@@ -117,7 +117,7 @@ void KMessageWidgetPrivate::createLayout()
     if (wordWrap) {
         QGridLayout *layout = new QGridLayout(q);
         // Set alignment to make sure icon does not move down if text wraps
-        layout->addWidget(iconLabel, 0, 0, 1, 1, Qt::AlignHCenter | Qt::AlignTop);
+        layout->addWidget(iconLabel, 0, 0, 1, 1, Qt::AlignCenter);
         layout->addWidget(textLabel, 0, 1);
 
         if (buttons.isEmpty()) {
@@ -139,7 +139,7 @@ void KMessageWidgetPrivate::createLayout()
         }
     } else {
         QHBoxLayout *layout = new QHBoxLayout(q);
-        layout->addWidget(iconLabel, 0, Qt::AlignTop);
+        layout->addWidget(iconLabel, 0, Qt::AlignVCenter);
         layout->addWidget(textLabel);
 
         for (QToolButton *button : std::as_const(buttons)) {
@@ -180,7 +180,6 @@ void KMessageWidgetPrivate::setPalette()
     palette.setColor(QPalette::Window, bgBaseColor);
     const QColor parentTextColor = (q->parentWidget() ? q->parentWidget()->palette() : qApp->palette()).color(QPalette::WindowText);
     palette.setColor(QPalette::WindowText, parentTextColor);
-    q->setPalette(palette);
     // Explicitly set the palettes of the labels because some apps use stylesheets which break the
     // palette propagation
     iconLabel->setPalette(palette);
@@ -311,7 +310,7 @@ bool KMessageWidget::event(QEvent *event)
 
     } else if (event->type() == QEvent::ParentChange) {
         d->setPalette();
-    } else if (event->type() == QEvent::ApplicationPaletteChange) {
+    } else if (event->type() == QEvent::PaletteChange) {
         d->setPalette();
     }
     return QFrame::event(event);
